sqltriples

Package sqltriples |
[show private | hide private]
[frames | no frames]

## Package sqltriples

    A simple SQL-accessible RDF triple store.

    Copyright (C) 2006, 2007 Paul Boddie <paul@boddie.org.uk>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA

    --------

    To initialise the database, first open a store:

    import sqltriples
    store = sqltriples.open(dbname, dbmodulename)

    Then, use the init method on the TripleStore object as follows:

    store.init()
    store.commit()

    See the attributes of the different adapter classes for details of the table and
    sequence employed.

    To remove the triple store objects from the database, use the delete method on
    the TripleStore object as follows:

    store.delete()
    store.commit()

    NOTE: The statements sent to the database system can be configured, but this
    NOTE: should be made convenient in future releases.

Submodules
`Adapters`: Database-specific adapter classes. `Query`: Database querying classes. `Store`: RDF triple store classes. `Types`: Special data types inheriting from the unicode type in order to provide interoperability with rdflib.

Function Summary
| ``open`(database_name, database_module_name, adapter, table_name, sequence_name, debug, **kw)` Open a triple store using either a connection identified by 'database_name' and using the given 'database_module_name' along with other keyword arguments, or using the given 'adapter' object.

Variable Summary
`str` | `__version__` = `'0.3.1'`

Function Details

### open(database_name=None, database_module_name=None, adapter=None, table_name=None, sequence_name=None, debug=0, **kw)
    Open a triple store using either a connection identified by 'database_name'
    and using the given 'database_module_name' along with other keyword
    arguments, or using the given 'adapter' object. If the optional 'table_name'
    and 'sequence_name' are provided, override the default settings in the
    TripleStore class in order to access stored information in the database. The
    optional 'debug' parameter (set to false by default) can be used to show the
    working of the triple store.

Variable Details

    ### __version__ Type: `str` Value:
        '0.3.1'

Generated by Epydoc 2.1 on Fri Jan 12 00:04:34 2007 | http://epydoc.sf.net